@@ -41,8 +41,8 @@ class Easyocrpipleline:
             dictionary[result[i][1]]["score"] = result[i][2]
         json_name = file.split('/')[-1].split('.')[0]
         # json log file create
-        print("/tmp/testfolder/"+json_name,'+++++++++++++++++++')
-        with open("/tmp/testfolder/"+json_name+".json", "w") as outfile:
+        print("log/"+json_name,'+++++++++++++++++++')
+        with open("log/"+json_name+".json", "w") as outfile:
             json.dump(dictionary, outfile)
 
     def image_process(self, path):
@@ -79,7 +79,7 @@ class Easyocrpipleline:
                 tif_file_path=path
             else:
                 img.seek(i)
-                tif_file_path=('/tmp/'+tif_file_name+'(%s).tif'%(i,))
+                tif_file_path=('folder/'+tif_file_name+'(%s).tif'%(i,))
                 img.save(tif_file_path)
             tif_file = cv2.imread(tif_file_path)  # in case of tif
             result = reader.readtext(tif_file, width_ths=0)
@@ -97,7 +97,7 @@ class Easyocrpipleline:
         file_name = path.split('/')[-1]
         file_name = file_name.split('.')[0]
         for index, image in enumerate(images):
-            path = '/tmp/'+file_name+'('+str(index)+').jpg'
+            path = 'folder/'+file_name+'('+str(index)+').jpg'
             image.save(path)
             self.image_process(path)
 
